window.Gleam.initSearch([{"doc":"scrapbook","title":"scrapbook","content":"# scrapbook\n\nGleam package for the Erlang target that can scrape parts of Facebook.\n\n**Currently, this package only supports scraping single events and events from a page (list of events or all event details).**\n\n[![Package Version](https://img.shields.io/hexpm/v/scrapbook)](https://hex.pm/packages/scrapbook)\n[![Package License](https://img.shields.io/hexpm/l/scrapbook)](https://hex.pm/packages/scrapbook)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/scrapbook/)\n![Target: Erlang](https://img.shields.io/badge/target-erlang-a90432)\n\n```sh\ngleam add scrapbook\n```\n\n```gleam\nimport gleam/io\nimport scrapbook/event\nimport scrapbook/page\n\npub fn main() {\n  let event =\n    event.scrape_from_url(\n      &quot;https://www.facebook.com/events/1137956700212933/1137956706879599/&quot;,\n    )\n  let _ = io.debug(event)\n\n  let events = page.scrape_upcoming_events_from_name(&quot;CodeSyncGlobal&quot;)\n  let _ = io.debug(events)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/scrapbook&gt;.\n\nAll contributions are welcome. If you have any questions, please create an issue in the repository.\n\n## Other information\n\nFacebook&#39;s terms of service prohibit automated scraping of their site. Use this package at your own risk.\n\nRead more: [Automated Data Collection Terms](https://www.facebook.com/legal/automated_data_collection_terms)\n\n## Acknowledgements\n\n- [@francescov1](https://github.com/francescov1) for the [facebook-event-scraper](https://github.com/francescov1/facebook-event-scraper) (MIT) TypeScript library, which was an inspiration and the basis for the event scraping logic.\n","url":"index.html"},{"doc":"scrapbook/error","title":"FetchError","content":"pub type FetchError {\n  RequestConstructionError(url: String)\n  HttpError(httpc.HttpError)\n  FollowRedirectionError\n}\n This type represents the reasons why fetching the HTTP data might fail.\nRequestConstructionError(url: String)\n Error constructing request from URL.\n\nHttpError(httpc.HttpError)\n Error sending the HTTP request.\n\nFollowRedirectionError\n Error following the redirection - no target URL found.\n\nSynonyms:\nscrapbook/error.FetchError\nscrapbook/error FetchError","url":"scrapbook/error.html#FetchError"},{"doc":"scrapbook/error","title":"FindKeyValueError","content":"pub type FindKeyValueError {\n  NoPrefix(key: String)\n  FindValueError(FindValueError)\n}\n This type represents the reasons why a key or its value could not be found.\nNoPrefix(key: String)\n No prefix with the specified key was found. This may mean that the prefix\n exists in JSON, but its value does not match the required structure and an\n attempt to find another occurrence of the key failed. \n\nFindValueError(FindValueError)\n Error finding a value.\n\nSynonyms:\nscrapbook/error.FindKeyValueError\nscrapbook/error FindKeyValueError","url":"scrapbook/error.html#FindKeyValueError"},{"doc":"scrapbook/error","title":"FindValueError","content":"pub type FindValueError {\n  NoValue\n  NoGraphemes\n  InvalidStartCharacter\n  NoValueEndFound(IndexSearchError)\n}\n This type represents the reasons why a value could not be found.\nNoValue\n The key had no assigned value - the value was null.\n\nNoGraphemes\n There were no graphemes in a list after converting from string.\n\nInvalidStartCharacter\n Invalid start character of a value - value of the key is not an object or\n an array.\n\nNoValueEndFound(IndexSearchError)\n Error in finding an index that indicates the end character of a value.\n\nSynonyms:\nscrapbook/error.FindValueError\nscrapbook/error FindValueError","url":"scrapbook/error.html#FindValueError"},{"doc":"scrapbook/error","title":"IndexSearchError","content":"pub type IndexSearchError {\n  NoIndexFound(last_index: Int)\n}\n This type represents the reasons why the search for the character index in\n string may fail.\nNoIndexFound(last_index: Int)\n Error finding an index with an index of a last analyzed character.\n\nSynonyms:\nscrapbook/error.IndexSearchError\nscrapbook/error IndexSearchError","url":"scrapbook/error.html#IndexSearchError"},{"doc":"scrapbook/error","title":"PropertyError","content":"pub type PropertyError {\n  FindKeyValueError(FindKeyValueError)\n  DecodeError(json.DecodeError)\n  ValidateError\n}\n This type represents the reasons why decoding of the JSON failed.\nFindKeyValueError(FindKeyValueError)\n Error in finding the desired key or its value.\n\nDecodeError(json.DecodeError)\n Error decoding JSON structure.\n\nValidateError\n Error validating decoded data with the passed validator.\n\nSynonyms:\nscrapbook/error.PropertyError\nscrapbook/error PropertyError","url":"scrapbook/error.html#PropertyError"},{"doc":"scrapbook/error","title":"ScrapeError","content":"pub type ScrapeError {\n  UrlError\n  FetchError(FetchError)\n  PropertyError(List(PropertyError))\n}\n This type represents the reasons why scraping the event might fail.\nUrlError\n Error creating the target URL from the input.\n\nFetchError(FetchError)\n Error retrieving event data.\n\nPropertyError(List(PropertyError))\n Error parsing a JSON property from received HTML.\n\nSynonyms:\nscrapbook/error.ScrapeError\nscrapbook/error ScrapeError","url":"scrapbook/error.html#ScrapeError"},{"doc":"scrapbook/error","title":"scrapbook/error","content":"","url":"scrapbook/error.html"},{"doc":"scrapbook/event","title":"EventBasicData","content":"pub opaque type EventBasicData\n\n\nSynonyms:\nscrapbook/event.EventBasicData\nscrapbook/event EventBasicData","url":"scrapbook/event.html#EventBasicData"},{"doc":"scrapbook/event","title":"EventData","content":"pub opaque type EventData\n\n\nSynonyms:\nscrapbook/event.EventData\nscrapbook/event EventData","url":"scrapbook/event.html#EventData"},{"doc":"scrapbook/event","title":"EventHost","content":"pub opaque type EventHost\n\n\nSynonyms:\nscrapbook/event.EventHost\nscrapbook/event EventHost","url":"scrapbook/event.html#EventHost"},{"doc":"scrapbook/event","title":"EventParent","content":"pub opaque type EventParent\n\n\nSynonyms:\nscrapbook/event.EventParent\nscrapbook/event EventParent","url":"scrapbook/event.html#EventParent"},{"doc":"scrapbook/event","title":"EventPhoto","content":"pub opaque type EventPhoto\n\n\nSynonyms:\nscrapbook/event.EventPhoto\nscrapbook/event EventPhoto","url":"scrapbook/event.html#EventPhoto"},{"doc":"scrapbook/event","title":"EventPlace","content":"pub opaque type EventPlace\n\n\nSynonyms:\nscrapbook/event.EventPlace\nscrapbook/event EventPlace","url":"scrapbook/event.html#EventPlace"},{"doc":"scrapbook/event","title":"EventSibling","content":"pub opaque type EventSibling\n\n\nSynonyms:\nscrapbook/event.EventSibling\nscrapbook/event EventSibling","url":"scrapbook/event.html#EventSibling"},{"doc":"scrapbook/event","title":"EventTimeDetails","content":"pub opaque type EventTimeDetails\n\n\nSynonyms:\nscrapbook/event.EventTimeDetails\nscrapbook/event EventTimeDetails","url":"scrapbook/event.html#EventTimeDetails"},{"doc":"scrapbook/event","title":"EventVideo","content":"pub opaque type EventVideo\n\n\nSynonyms:\nscrapbook/event.EventVideo\nscrapbook/event EventVideo","url":"scrapbook/event.html#EventVideo"},{"doc":"scrapbook/event","title":"HostType","content":"pub type HostType {\n  User\n  Page\n}\n\nUser\n\n\nPage\n\n\nSynonyms:\nscrapbook/event.HostType\nscrapbook/event HostType","url":"scrapbook/event.html#HostType"},{"doc":"scrapbook/event","title":"OfflineCity","content":"pub opaque type OfflineCity\n\n\nSynonyms:\nscrapbook/event.OfflineCity\nscrapbook/event OfflineCity","url":"scrapbook/event.html#OfflineCity"},{"doc":"scrapbook/event","title":"OfflineLocation","content":"pub opaque type OfflineLocation\n\n\nSynonyms:\nscrapbook/event.OfflineLocation\nscrapbook/event OfflineLocation","url":"scrapbook/event.html#OfflineLocation"},{"doc":"scrapbook/event","title":"OfflineType","content":"pub type OfflineType {\n  Text\n  Place\n  City\n}\n\nText\n\n\nPlace\n\n\nCity\n\n\nSynonyms:\nscrapbook/event.OfflineType\nscrapbook/event OfflineType","url":"scrapbook/event.html#OfflineType"},{"doc":"scrapbook/event","title":"OnlineType","content":"pub type OnlineType {\n  MessengerRoom\n  ThirdParty\n  FacebookLive\n  Other\n}\n\nMessengerRoom\n\n\nThirdParty\n\n\nFacebookLive\n\n\nOther\n\n\nSynonyms:\nscrapbook/event.OnlineType\nscrapbook/event OnlineType","url":"scrapbook/event.html#OnlineType"},{"doc":"scrapbook/event","title":"get_event","content":"pub fn get_event(\n  html: String,\n) -&gt; Result(EventData, List(PropertyError))\n Get all possible event data from the given HTML string.\nSynonyms:\nscrapbook/event.get_event\nscrapbook/event get_event","url":"scrapbook/event.html#get_event"},{"doc":"scrapbook/event","title":"scrape_from_id","content":"pub fn scrape_from_id(\n  id: String,\n) -&gt; Result(EventData, ScrapeError)\n Scrape an event from the specified event id.\nSynonyms:\nscrapbook/event.scrape_from_id\nscrapbook/event scrape_from_id","url":"scrapbook/event.html#scrape_from_id"},{"doc":"scrapbook/event","title":"scrape_from_url","content":"pub fn scrape_from_url(\n  url: String,\n) -&gt; Result(EventData, ScrapeError)\n Scrape an event from the specified event URL.\nSynonyms:\nscrapbook/event.scrape_from_url\nscrapbook/event scrape_from_url","url":"scrapbook/event.html#scrape_from_url"},{"doc":"scrapbook/event","title":"scrapbook/event","content":"","url":"scrapbook/event.html"},{"doc":"scrapbook/page","title":"PageEventCollection","content":"pub opaque type PageEventCollection\n\n\nSynonyms:\nscrapbook/page.PageEventCollection\nscrapbook/page PageEventCollection","url":"scrapbook/page.html#PageEventCollection"},{"doc":"scrapbook/page","title":"PageEventItem","content":"pub opaque type PageEventItem\n\n\nSynonyms:\nscrapbook/page.PageEventItem\nscrapbook/page PageEventItem","url":"scrapbook/page.html#PageEventItem"},{"doc":"scrapbook/page","title":"get_event_collection","content":"pub fn get_event_collection(\n  html: String,\n) -&gt; Result(PageEventCollection, List(PropertyError))\n Get a collection of page event items from the given HTML string.\nSynonyms:\nscrapbook/page.get_event_collection\nscrapbook/page get_event_collection","url":"scrapbook/page.html#get_event_collection"},{"doc":"scrapbook/page","title":"scrape_event_collection_from_url","content":"pub fn scrape_event_collection_from_url(\n  url: String,\n) -&gt; Result(PageEventCollection, ScrapeError)\n Scrape the event items collection from the specified page events URL.\nSynonyms:\nscrapbook/page.scrape_event_collection_from_url\nscrapbook/page scrape_event_collection_from_url","url":"scrapbook/page.html#scrape_event_collection_from_url"},{"doc":"scrapbook/page","title":"scrape_events_from_url","content":"pub fn scrape_events_from_url(\n  url: String,\n) -&gt; Result(List(EventData), ScrapeError)\n Scrape all possible event data for the event collection from the specified\n page events URL.\nSynonyms:\nscrapbook/page.scrape_events_from_url\nscrapbook/page scrape_events_from_url","url":"scrapbook/page.html#scrape_events_from_url"},{"doc":"scrapbook/page","title":"scrape_past_event_collection_from_name","content":"pub fn scrape_past_event_collection_from_name(\n  name: String,\n) -&gt; Result(PageEventCollection, ScrapeError)\n Scrape the collection of past event items from the specified page name.\nSynonyms:\nscrapbook/page.scrape_past_event_collection_from_name\nscrapbook/page scrape_past_event_collection_from_name","url":"scrapbook/page.html#scrape_past_event_collection_from_name"},{"doc":"scrapbook/page","title":"scrape_past_events_from_name","content":"pub fn scrape_past_events_from_name(\n  name: String,\n) -&gt; Result(List(EventData), ScrapeError)\n Scrape all possible event data for the past events collection from the\n specified page name.\nSynonyms:\nscrapbook/page.scrape_past_events_from_name\nscrapbook/page scrape_past_events_from_name","url":"scrapbook/page.html#scrape_past_events_from_name"},{"doc":"scrapbook/page","title":"scrape_upcoming_event_collection_from_name","content":"pub fn scrape_upcoming_event_collection_from_name(\n  name: String,\n) -&gt; Result(PageEventCollection, ScrapeError)\n Scrape the collection of upcoming event items from the specified page name.\nSynonyms:\nscrapbook/page.scrape_upcoming_event_collection_from_name\nscrapbook/page scrape_upcoming_event_collection_from_name","url":"scrapbook/page.html#scrape_upcoming_event_collection_from_name"},{"doc":"scrapbook/page","title":"scrape_upcoming_events_from_name","content":"pub fn scrape_upcoming_events_from_name(\n  name: String,\n) -&gt; Result(List(EventData), ScrapeError)\n Scrape all possible event data for the upcoming events collection from the\n specified page name.\nSynonyms:\nscrapbook/page.scrape_upcoming_events_from_name\nscrapbook/page scrape_upcoming_events_from_name","url":"scrapbook/page.html#scrape_upcoming_events_from_name"},{"doc":"scrapbook/page","title":"scrapbook/page","content":"","url":"scrapbook/page.html"}]);